@@ -552,6 +552,16 @@ static void parseOpts(int argc, char **argv)
     if (profile != NULL)
       colorProfile = cmsOpenProfileFromFile(profile,"r");    
 
+#ifdef HAVE_CUPS_1_7
+    if ((attr = ppdFindAttr(ppd,"PWGRaster",0)) != 0 &&
+	(!strcasecmp(attr->value, "true")
+	 || !strcasecmp(attr->value, "on") ||
+	 !strcasecmp(attr->value, "yes")))
+    {
+      pwgraster = 1;
+      cupsRasterParseIPPOptions(&header, num_options, options, pwgraster, 0);
+    }
+#endif /* HAVE_CUPS_1_7 */
   } else {
 #ifdef HAVE_CUPS_1_7
     pwgraster = 1;
@@ -1414,8 +1424,7 @@ static void selectConvertFunc(cups_raster_t *raster)
   }
   allocLineBuf = true;
 
-  if (colorProfile != NULL && popplerColorProfile != colorProfile 
-      && !cm_disabled) {
+  if (colorProfile != NULL && popplerColorProfile != colorProfile) {
     unsigned int bytes;
 
     switch (header.cupsColorSpace) {
@@ -1471,9 +1480,6 @@ static void selectConvertFunc(cups_raster_t *raster)
       pdfError(-1,const_cast<char *>("Can't create color transform"));
       exit(1);
     }
-  } else if (cm_disabled) {
-    convertCSpace = convertCSpaceNone;
-    convertBits = convertBitsNoop;
   } else {
     /* select convertCSpace function */
     switch (header.cupsColorSpace) {
